#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_ICEIL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_ICEIL_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/iceil.hpp>

#endif
